#! /bin/sh -

CPOLIS_REPO_URL="https://git.streifling.com/api/v1/repos/jason/cpolis/releases"
EXTRACTION_DIR=$HOME
CPOLIS_DIR=$EXTRACTION_DIR/cpolis
TAILWINDCSS_REPO_URL=https://api.github.com/repos/tailwindlabs/tailwindcss/releases/latest
TMP_DIR=/tmp
BIN_DIR=/usr/local/bin
SYSTEMD_DIR=/lib/systemd/system

! groups | grep -E 'root|wheel|sudo' && echo "You need administrative privileges for this script" && exit 1

! which curl >/dev/null 2>&1 && echo "curl needs to be installed" >&2 && exit 1
! which go >/dev/null 2>&1 && echo "go needs to be installed" >&2 && exit 1
! which jq >/dev/null 2>&1 && echo "jq needs to be installed" >&2 && exit 1
! which tar >/dev/null 2>&1 && echo "tar needs to be installed" >&2 && exit 1
! which xargs >/dev/null 2>&1 && echo "xargs needs to be installed" >&2 && exit 1

rm -fr $CPOLIS_DIR/*
latest_release=$(curl -s $CPOLIS_REPO_URL | jq -r '.[0].tag_name')
curl -Lo $TMP_DIR/cpolis.tar.gz https://git.streifling.com/jason/cpolis/archive/$latest_release.tar.gz
tar -xzf $TMP_DIR/cpolis.tar.gz -C $EXTRACTION_DIR
rm $TMP_DIR/cpolis.tar.gz

curl -s $TAILWINDCSS_REPO_URL |
    grep -F browser_download_url |
    grep -F linux-x64 |
    cut -d'"' -f4 |
    xargs -r curl -Lo $CPOLIS_DIR/tailwindcss
chmod +x $CPOLIS_DIR/tailwindcss
$CPOLIS_DIR/tailwindcss -i web/static/css/input.css -o web/static/css/style.css

go build -o $TMP_DIR/cpolis $CPOLIS_DIR/cmd/main.go
sudo mv $TMP_DIR/cpolis $BIN_DIR/cpolis
chmod +x $BIN_DIR/cpolis

[ ! -f $SYSTEMD_DIR ] && mkdir -p $SYSTEMD_DIR
sudo mv $CPOLIS_DIR/cpolis.service $SYSTEMD_DIR
sudo systemctl daemon-reload
sudo systemctl is-active --quiet cpolis.service && sudo systemctl restart cpolis.service
